==> haskell-crypto-cipher-types-0.0.9-264-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-cipher-types
version:              0.0.9
visibility:           public
id:                   crypto-cipher-types-0.0.9-Eb32mKWiXi08hJgQY526gG
key:                  crypto-cipher-types-0.0.9-Eb32mKWiXi08hJgQY526gG
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-crypto-cipher
synopsis:             Generic cryptography cipher types
description:          Generic cryptography cipher types
category:             Cryptography
abi:                  f4dea2c9aabb97347cb272c74b2d72a2
exposed:              True
exposed-modules:      Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules:
    Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
    Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
    Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
    Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypto-cipher-types-0.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypto-cipher-types-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-cipher-types
hs-libraries:         HScrypto-cipher-types-0.0.9-Eb32mKWiXi08hJgQY526gG
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1 securemem-0.1.10-IqxMuGzWgkb4DS0vuOrIox

haddock-interfaces:
    /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-cipher-types-0.0.9-293-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-cipher-types
version:              0.0.9
visibility:           public
id:                   crypto-cipher-types-0.0.9-8dNq76lIVvq61pUzJfYm3b
key:                  crypto-cipher-types-0.0.9-8dNq76lIVvq61pUzJfYm3b
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-crypto-cipher
synopsis:             Generic cryptography cipher types
description:          Generic cryptography cipher types
category:             Cryptography
abi:                  0bb2ad88efe60806437abf563108666d
exposed:              True
exposed-modules:      Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules:
    Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
    Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
    Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
    Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypto-cipher-types-0.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypto-cipher-types-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-cipher-types
hs-libraries:         HScrypto-cipher-types-0.0.9-8dNq76lIVvq61pUzJfYm3b
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1 securemem-0.1.10-IeO5K0X0mzS7xQCiSaDnT0

haddock-interfaces:
    /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
